/* Developed for Lenovo Educational Board Pass 3
   © Lenovo Created by Joshua Grosser
   v. 2.0 */

#include <ArduinoBLE.h>

BLEService ledService("19B10000-E8F2-537E-4F6C-D104768A1214"); // Bluetooth LED Information

BLEByteCharacteristic switchCharacteristic("19B10001-E8F2-537E-4F6C-D104768A1214", BLERead | BLEWrite); // Bluetooth Readable and Writable UUID

const int led = 15; // Green LED pin

void setup() {
  // Begin serial at 115200 baud rate
  Serial.begin(115200);

  // Setup LED pin
  pinMode(led, OUTPUT);

  // Initialize Bluetooth
  BLE.begin();

  // Set discoverable name and UUID
  BLE.setLocalName("Lenovo Educational Board");

  // Setup Bluetooth connections correctly and write value of 0
  BLE.setAdvertisedService(ledService);
  ledService.addCharacteristic(switchCharacteristic);
  BLE.addService(ledService);
  switchCharacteristic.writeValue(0);
  BLE.advertise();
  Serial.println("Bluetooth correctly initialized.");
}

void loop() {
  // Listen for connecting Bluetooth devices
  BLEDevice central = BLE.central();

  // If devices are connected
  if (central) {
    // Print connected device MAC address
    Serial.print("Connected to device: ");
    Serial.println(central.address());

    // While device is connected
    while (central.connected()) {
      // If value is written to Bluetooth
      if (switchCharacteristic.written()) {
        if (switchCharacteristic.value() == 1) { // A value of 1
          // Turn on LED
          Serial.println("LED on");
          digitalWrite(led, HIGH);
        } else if (switchCharacteristic.value() == 0) { // A 0 value
          // Turn off LED
          Serial.println("LED off");
          digitalWrite(led, LOW);
        }
      }
    }

    // If device disconnects print MAC address
    Serial.print("Disconnected from device: ");
    Serial.println(central.address());
  }
}
