/* Developed for Lenovo Educational Board Pass 3
   © Lenovo Created by Joshua Grosser
   v. 2.0 */

// include the following libraries
#include <Wire.h>
#include <SparkFun_APDS9960.h>

// object creation
SparkFun_APDS9960 apds = SparkFun_APDS9960();

uint8_t proximity_data = 0; // proximity value
const float midC = 256.0; // the hz value of middle C
const int piezoPin = 11; // the number of the buzzer pin

void setup() {
  // Initialize Serial port
  Serial.begin(9600);
  pinMode(piezoPin,OUTPUT);
  // Initialize gesture sensor for proximity
  apds.init();
  apds.enableProximitySensor(false);
  apds.setProximityGain(PGAIN_2X);
}

void loop() {
  // Read the proximity value
  apds.readProximity(proximity_data);
  // each test case is in a loop if proximity is within a threshold
  while(proximity_data < 15)
  {
    myTone(piezoPin, midC, 250); 
    delay(1100);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 15 && proximity_data < 25)
  {
    myTone(piezoPin, midC, 250); 
    delay(900);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 25 && proximity_data < 50)
  {
    myTone(piezoPin, midC, 250); 
    delay(700);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 50 && proximity_data < 100)
  {
    myTone(piezoPin, midC, 250); 
    delay(500);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 100 && proximity_data < 150)
  {
    myTone(piezoPin, midC, 250); 
    delay(300);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 150 && proximity_data < 200)
  {
    myTone(piezoPin, midC, 250); 
    delay(200);
    apds.readProximity(proximity_data);
  }
  while(proximity_data >= 200)
  {
    myTone(piezoPin, midC, 250); 
    delay(100);
    apds.readProximity(proximity_data);
  }
}

void myTone(byte pin, uint16_t frequency, uint16_t duration) 
{ // input parameters: Arduino pin number, frequency in Hz, duration in milliseconds
  // plays the tone we want by using the vibrations of the buzzer
  unsigned long startTime=millis();
  unsigned long halfPeriod= 1000000L/frequency/2;
  while (millis()-startTime< duration)
  {
    digitalWrite(pin,HIGH);
    delayMicroseconds(halfPeriod);
    digitalWrite(pin,LOW);
    delayMicroseconds(halfPeriod);
  }
}
