/* Developed for Lenovo Educational Board Pass 3
   © Lenovo Created by Joshua Grosser
   v. 2.0 */

#include "EEPROM.h"

uint32_t randComputer = 0; // random number selected by computer
uint32_t randGuess = 0; // your guess
int bootCount = 0; // keeps track of number of loops

// create EEPROM classes
EEPROMClass  RANDCOMP("eeprom0");
EEPROMClass  GUESS("eeprom1");

void setup() {
  // set baud rate
  Serial.begin(115200);
  delay(1000);
  // begin EEPROM classes
  RANDCOMP.begin(0x500);
  GUESS.begin(0x200);
  Serial.println("Please input a number 1, 2, or 3");
}

void loop() {
  while(Serial.available() > 0)
  {
    randGuess = Serial.parseInt(); 
    // A newline character indicates end of input
    if(Serial.read() == '\n')
    {
      //Increment boot number
      ++bootCount;
      // Adjust the values if out of range
      randGuess = constrain(randGuess, 1, 3);
      // select random number in range 1-3
      randComputer = random(1, 4); 
      
      //Write: Variables ---> EEPROM stores
      RANDCOMP.put(0, randComputer);
      GUESS.put(0, randGuess);
      Serial.println("Writing to EEPROM:");
      Serial.print("Your Guess: ");    Serial.println(randGuess);
      Serial.println("------------------------------------\n");
      
      // Clear variables
      randComputer = 0;
      randGuess = 0;
      Serial.println("Clearing variables");
      Serial.print("Computer Number: ");    Serial.println(randComputer);
      Serial.print("Your Guess: ");    Serial.println(randGuess);
      Serial.println("------------------------------------\n");
      delay(3000); // wait 3 seconds before displaying computer number
      
      // Read: Variables <--- EEPROM stores
      RANDCOMP.get(0, randComputer);
      GUESS.get(0, randGuess);
      Serial.println("Reading from EEPROM:");
      Serial.print("Computer Number: ");    Serial.println(randComputer);
      Serial.print("Your Guess: ");    Serial.println(randGuess);
      Serial.println("------------------------------------\n");
      Serial.println();
      if (randComputer == randGuess) // if guessed correctly
      {
        Serial.println("You have guess correctly!");
        delay(0xFFFFFFFF); // max delay value to prevent looping
      }
      else if (bootCount >= 5) // if you ran out of attempts
      {
        Serial.println("Sorry you have run out of attempts.");
        delay(0xFFFFFFFF); // max delay value to prevent looping
      }
      else // print selection statement before looping again
      {
        Serial.println("Please input a number 1, 2, or 3");
      }
    }
  }
}
